==> ddd-3.1.4.tar.gz: ddd-3.1.4/ddd/acspecial.h <==
ICE_CHECK_DECL(_getpty, unistd.h)
ICE_CHECK_DECL(alloca, alloca.h stdlib.h)
ICE_CHECK_DECL(asctime, time.h)
ICE_CHECK_DECL(clock, time.h)
ICE_CHECK_DECL(difftime, time.h)
ICE_CHECK_DECL(dup2, unistd.h)
ICE_CHECK_DECL(endpwent, pwd.h)
ICE_CHECK_DECL(fcntl, fcntl.h)
ICE_CHECK_DECL(ftime, sys/timeb.h)
ICE_CHECK_DECL(gethostbyname, netdb.h)
ICE_CHECK_DECL(gethostname, unistd.h)
ICE_CHECK_DECL(getpt, stdlib.h)
ICE_CHECK_DECL(getpty, unistd.h)
ICE_CHECK_DECL(getrlimit, sys/resource.h)
ICE_CHECK_DECL(getrusage, sys/resource.h)
ICE_CHECK_DECL(getwd, unistd.h)
ICE_CHECK_DECL(grantpt, stdlib.h)
ICE_CHECK_DECL(hypot, math.h)
ICE_CHECK_DECL(ioctl, unistd.h sys/ioctl.h)
ICE_CHECK_DECL(link, unistd.h)
ICE_CHECK_DECL(lstat, sys/stat.h)
ICE_CHECK_DECL(malloc, stdlib.h)
ICE_CHECK_DECL(memcpy, string.h)
ICE_CHECK_DECL(memset, string.h)
ICE_CHECK_DECL(pclose, stdio.h)
ICE_CHECK_DECL(popen, stdio.h)
ICE_CHECK_DECL(ptrace, unistd.h sys/ptrace.h)
ICE_CHECK_DECL(ptsname, stdlib.h)
ICE_CHECK_DECL(raise, signal.h)
ICE_CHECK_DECL(rand, stdlib.h)
ICE_CHECK_DECL(random, stdlib.h)
ICE_CHECK_DECL(readlink, unistd.h)
ICE_CHECK_DECL(setbuf, stdio.h)
ICE_CHECK_DECL(setpgid, unistd.h)
ICE_CHECK_DECL(setpgrp, unistd.h)
ICE_CHECK_DECL(setpgrp2, unistd.h)
ICE_CHECK_DECL(setpwent, pwd.h)
ICE_CHECK_DECL(setrlimit, sys/resource.h)
ICE_CHECK_DECL(setsid, unistd.h)
ICE_CHECK_DECL(setvbuf, stdio.h)
ICE_CHECK_DECL(sigblock, signal.h)
ICE_CHECK_DECL(sigprocmask, signal.h)
ICE_CHECK_DECL(sigsetmask, signal.h)
ICE_CHECK_DECL(sigsuspend, signal.h)
ICE_CHECK_DECL(srand, stdlib.h)
ICE_CHECK_DECL(srandom, stdlib.h)
ICE_CHECK_DECL(stat, sys/stat.h)
ICE_CHECK_DECL(strerror, string.h)
ICE_CHECK_DECL(strftime, time.h)
ICE_CHECK_DECL(strsignal, string.h)
ICE_CHECK_DECL(strtod, stdlib.h)
ICE_CHECK_DECL(strtol, stdlib.h)
ICE_CHECK_DECL(strtoul, stdlib.h)
ICE_CHECK_DECL(symlink, unistd.h)
ICE_CHECK_DECL(tcdrain, termios.h)
ICE_CHECK_DECL(tcflow, termios.h)
ICE_CHECK_DECL(tcflush, termios.h)
ICE_CHECK_DECL(tcgetattr, termios.h)
ICE_CHECK_DECL(tcgetpgrp, unistd.h)
ICE_CHECK_DECL(tcgetsid, sys/termios.h)
ICE_CHECK_DECL(tcsendbreak, termios.h)
ICE_CHECK_DECL(tcsetattr, termios.h)
ICE_CHECK_DECL(tcsetpgrp, unistd.h)
ICE_CHECK_DECL(times, sys/times.h)
ICE_CHECK_DECL(uname, sys/utsname.h)
ICE_CHECK_DECL(unlink, unistd.h)
ICE_CHECK_DECL(unlockpt, stdlib.h)
ICE_CHECK_DECL(waitpid, sys/wait.h)

==> ddd-3.1.6.tar.gz: ddd-3.1.6/ddd/acspecial.h <==
ICE_CHECK_DECL(_getpty, unistd.h)
ICE_CHECK_DECL(alloca, alloca.h stdlib.h)
ICE_CHECK_DECL(asctime, time.h)
ICE_CHECK_DECL(clock, time.h)
ICE_CHECK_DECL(difftime, time.h)
ICE_CHECK_DECL(dup2, unistd.h)
ICE_CHECK_DECL(endpwent, pwd.h)
ICE_CHECK_DECL(fcntl, fcntl.h)
ICE_CHECK_DECL(ftime, sys/timeb.h)
ICE_CHECK_DECL(gethostbyname, netdb.h)
ICE_CHECK_DECL(gethostname, unistd.h)
ICE_CHECK_DECL(getpt, stdlib.h)
ICE_CHECK_DECL(getpty, unistd.h)
ICE_CHECK_DECL(getrlimit, sys/resource.h)
ICE_CHECK_DECL(getrusage, sys/resource.h)
ICE_CHECK_DECL(getwd, unistd.h)
ICE_CHECK_DECL(grantpt, stdlib.h)
ICE_CHECK_DECL(hypot, math.h)
ICE_CHECK_DECL(ioctl, unistd.h sys/ioctl.h)
ICE_CHECK_DECL(link, unistd.h)
ICE_CHECK_DECL(lstat, sys/stat.h)
ICE_CHECK_DECL(malloc, stdlib.h)
ICE_CHECK_DECL(memcpy, string.h)
ICE_CHECK_DECL(memset, string.h)
ICE_CHECK_DECL(pclose, stdio.h)
ICE_CHECK_DECL(popen, stdio.h)
ICE_CHECK_DECL(ptrace, unistd.h sys/ptrace.h)
ICE_CHECK_DECL(ptsname, stdlib.h)
ICE_CHECK_DECL(raise, signal.h)
ICE_CHECK_DECL(rand, stdlib.h)
ICE_CHECK_DECL(random, stdlib.h)
ICE_CHECK_DECL(readlink, unistd.h)
ICE_CHECK_DECL(setbuf, stdio.h)
ICE_CHECK_DECL(setpgid, unistd.h)
ICE_CHECK_DECL(setpgrp, unistd.h)
ICE_CHECK_DECL(setpgrp2, unistd.h)
ICE_CHECK_DECL(setpwent, pwd.h)
ICE_CHECK_DECL(setrlimit, sys/resource.h)
ICE_CHECK_DECL(setsid, unistd.h)
ICE_CHECK_DECL(setvbuf, stdio.h)
ICE_CHECK_DECL(sigblock, signal.h)
ICE_CHECK_DECL(sigprocmask, signal.h)
ICE_CHECK_DECL(sigsetmask, signal.h)
ICE_CHECK_DECL(sigsuspend, signal.h)
ICE_CHECK_DECL(srand, stdlib.h)
ICE_CHECK_DECL(srandom, stdlib.h math.h)
ICE_CHECK_DECL(stat, sys/stat.h)
ICE_CHECK_DECL(strerror, string.h)
ICE_CHECK_DECL(strftime, time.h)
ICE_CHECK_DECL(strsignal, string.h)
ICE_CHECK_DECL(strtod, stdlib.h)
ICE_CHECK_DECL(strtol, stdlib.h)
ICE_CHECK_DECL(strtoul, stdlib.h)
ICE_CHECK_DECL(symlink, unistd.h)
ICE_CHECK_DECL(tcdrain, termios.h)
ICE_CHECK_DECL(tcflow, termios.h)
ICE_CHECK_DECL(tcflush, termios.h)
ICE_CHECK_DECL(tcgetattr, termios.h)
ICE_CHECK_DECL(tcgetpgrp, unistd.h)
ICE_CHECK_DECL(tcgetsid, sys/termios.h)
ICE_CHECK_DECL(tcsendbreak, termios.h)
ICE_CHECK_DECL(tcsetattr, termios.h)
ICE_CHECK_DECL(tcsetpgrp, unistd.h)
ICE_CHECK_DECL(times, sys/times.h)
ICE_CHECK_DECL(uname, sys/utsname.h)
ICE_CHECK_DECL(unlink, unistd.h)
ICE_CHECK_DECL(unlockpt, stdlib.h)
ICE_CHECK_DECL(waitpid, sys/wait.h)
